@@ -4,7 +4,7 @@ use 5.6.1;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Test::Builder;
 use Test::LongString;
@@ -22,9 +22,13 @@ sub import {
     no strict 'refs';
     *{$caller.'::page_like'}   = \&page_like;
     *{$caller.'::page_unlike'} = \&page_unlike;
+    *{$caller.'::user_agent'}  = \&user_agent;
 
     $Test->exported_to($caller);
     $Test->plan(@_);
+
+    # Default user agent is IE 6, but it can be switched with user_agent().
+    $Mech->agent_alias('Windows IE 6');
 }
 
 sub page_like($$;$) {
@@ -51,8 +55,14 @@ sub _trimmed_url {
        ? substr($url,0,$Test::WWW::display_length) . "..."
        : $url;
 }
-    
+
+sub user_agent {
+   my $agent = shift || 'WWW-Mechanize';
+   $Mech->agent_alias($agent);
+}    
+
 1;
+
 __END__
 
 =head1 NAME
@@ -62,14 +72,18 @@ Test::WWW::Simple - Test Web applications using TAP
 =head1 SYNOPSIS
 
   use Test::WWW::Simple;
+  # This is the default user agent.
+  user_agent('Windows IE 6');
   page_like("http://yahoo.com",      qr/.../, "check for expected text");
   page_unlike("http://my.yahoo.com", qr/.../, "check for undesirable text");
+  user_agent('Mac Safari');
+  ...
 
 =head1 DESCRIPTION
 
-C<Test::WWW::Simple> is a very basic class for testing Web applications and Web pages. It uses
-L<WWW::Mechanize> to fetch pages, and L<Test::Builder> to implement the TAP
-(Test Anything Protocol) for the actual testing.
+C<Test::WWW::Simple> is a very basic class for testing Web applications and 
+Web pages. It uses L<WWW::Mechanize> to fetch pages, and L<Test::Builder> to 
+implement TAP (Test Anything Protocol) for the actual testing.
 
 Since we use L<Test::Builder> for the C<like> and C<unlike> routines, these
 can be integrated with the other standard L<Test::Builder>-based modules
@@ -80,6 +94,10 @@ as just more tests.
 L<WWW::Mechanize> for a description of how the simulated browser works; 
 L<Test::Builder> to see how a test module works.
 
+You may also want to look at L<Test::WWW::Mechanize> if you want to write 
+more precise tests ("is the title of this page like the pattern?" or
+"are all the page links ok?").
+
 =head1 AUTHOR
 
 Joe McMahon, E<lt>mcmahon@yahoo-inc.comE<gt>
